@@ -29,7 +29,6 @@ import io
 import os
 import posixpath
 import re
-import stat
 import sys
 import warnings
 from collections import namedtuple
@@ -59,7 +58,8 @@ MAX_CONFIG_SEARCH_DEPTH = 25  # The number of parent directories isort will look
 DEFAULT_SECTIONS = ('FUTURE', 'STDLIB', 'THIRDPARTY', 'FIRSTPARTY', 'LOCALFOLDER')
 
 safety_exclude_re = re.compile(
-    r"/(\.eggs|\.git|\.hg|\.mypy_cache|\.nox|\.tox|\.venv|_build|buck-out|build|dist|lib/python[0-9].[0-9]+)/"
+    r"/(\.eggs|\.git|\.hg|\.mypy_cache|\.nox|\.tox|\.venv|_build|buck-out|build|dist|\.pants\.d"
+    r"|lib/python[0-9].[0-9]+)/"
 )
 
 WrapModes = ('GRID', 'VERTICAL', 'HANGING_INDENT', 'VERTICAL_HANGING_INDENT', 'VERTICAL_GRID', 'VERTICAL_GRID_GROUPED',
@@ -117,7 +117,7 @@ default = {'force_to_top': [],
                                       'test', 'textwrap', 'this', 'thread', 'threading', 'time', 'timeit', 'tkinter',
                                       'token', 'tokenize', 'trace', 'traceback', 'tracemalloc', 'ttk', 'tty', 'turtle',
                                       'turtledemo', 'types', 'typing', 'unicodedata', 'unittest', 'urllib', 'urllib2',
-                                      'urlparse', 'user', 'usercustomize', 'uu', 'uuid', 'venv', 'videoreader',
+                                      'urlparse', 'usercustomize', 'uu', 'uuid', 'venv', 'videoreader',
                                       'warnings', 'wave', 'weakref', 'webbrowser', 'whichdb', 'winreg', 'winsound',
                                       'wsgiref', 'xdrlib', 'xml', 'xmlrpc', 'xmlrpclib', 'zipapp', 'zipfile',
                                       'zipimport', 'zlib'],
@@ -130,6 +130,7 @@ default = {'force_to_top': [],
            'length_sort': False,
            'add_imports': [],
            'remove_imports': [],
+           'reverse_relative': False,
            'force_single_line': False,
            'default_section': 'FIRSTPARTY',
            'import_heading_future': '',
@@ -161,7 +162,8 @@ default = {'force_to_top': [],
            'no_lines_before': [],
            'no_inline_sort': False,
            'ignore_comments': False,
-           'safety_excludes': True}
+           'safety_excludes': True,
+           'case_sensitive': False}
 
 
 @lru_cache()
@@ -287,10 +289,10 @@ def _get_config_data(file_path, sections):
                         config_section = config_section.get(key, {})
                     settings.update(config_section)
             else:
-                warnings.warn(
-                    "Found %s but toml package is not installed. To configure"
-                    "isort with %s, install with 'isort[pyproject]'." % (file_path, file_path)
-                )
+                if '[tool.isort]' in config_file.read():
+                    warnings.warn("Found {} with [tool.isort] section, but toml package is not installed. "
+                                  "To configure isort with {}, install with 'isort[pyproject]'.".format(file_path,
+                                                                                                        file_path))
         else:
             if file_path.endswith('.editorconfig'):
                 line = '\n'
@@ -316,12 +318,20 @@ def _get_config_data(file_path, sections):
     return settings
 
 
-def should_skip(filename, config, path='/'):
-    """Returns True if the file should be skipped based on the passed in settings."""
-    normalized_path = posixpath.join(path.replace('\\', '/'), filename)
+def should_skip(filename, config, path=''):
+    """Returns True if the file and/or folder should be skipped based on the passed in settings."""
+    os_path = os.path.join(path, filename)
 
-    if config['safety_excludes'] and safety_exclude_re.search(normalized_path):
-        return True
+    normalized_path = os_path.replace('\\', '/')
+    if normalized_path[1:2] == ':':
+        normalized_path = normalized_path[2:]
+
+    if path and config['safety_excludes']:
+        check_exclude = '/' + filename.replace('\\', '/') + '/'
+        if path and os.path.basename(path) in ('lib', ):
+            check_exclude = '/' + os.path.basename(path) + check_exclude
+        if safety_exclude_re.search(check_exclude):
+            return True
 
     for skip_path in config['skip']:
         if posixpath.abspath(normalized_path) == posixpath.abspath(skip_path.replace('\\', '/')):
@@ -334,10 +344,10 @@ def should_skip(filename, config, path='/'):
         position = os.path.split(position[0])
 
     for glob in config['skip_glob']:
-        if fnmatch.fnmatch(filename, glob):
+        if fnmatch.fnmatch(filename, glob) or fnmatch.fnmatch('/' + filename, glob):
             return True
 
-    if stat.S_ISFIFO(os.stat(normalized_path).st_mode):
+    if not (os.path.isfile(os_path) or os.path.isdir(os_path) or os.path.islink(os_path)):
         return True
 
     return False
